@@ -1,11 +1,16 @@
 
-
 # Check that reformat_GSOD functions properly ----------------------------------
 context("reformat_GSOD")
 file.remove(file.path(tempdir(), list.files(tempdir(), pattern = ".op.gz$")))
 test_that("reformat_GSOD file_list parameter reformats data properly", {
   skip_on_cran()
 
+  do.call(file.remove, list(list.files(
+    tempdir(),
+    pattern = ".gz$",
+    full.names = TRUE
+  )))
+
   ftp_base <- "ftp://ftp.ncdc.noaa.gov/pub/data/gsod/1960/"
   test_files <-
     c("066000-99999-1960.op.gz", "066200-99999-1960.op.gz")
@@ -41,5 +46,4 @@ test_that("reformat_GSOD file_list parameter reformats data properly", {
 
   unlink(destinations)
 
-
 })
