@@ -1,3 +1,4 @@
+
 context("update_station_list")
 
 # Timeout options are reset on update_station_list() exit ---------------
@@ -13,7 +14,22 @@ test_that("update_station_list() downloads and imports proper file", {
   update_station_list()
   load(system.file("extdata", "isd_history.rda", package = "GSODR"))
   expect_equal(ncol(isd_history), 13)
-  expect_named(isd_history, c("USAF", "WBAN", "STN_NAME", "CTRY", "STATE",
-                              "CALL", "LAT", "LON", "ELEV_M", "BEGIN", "END",
-                              "STNID", "ELEV_M_SRTM_90m"))
+  expect_named(
+    isd_history,
+    c(
+      "USAF",
+      "WBAN",
+      "STN_NAME",
+      "CTRY",
+      "STATE",
+      "CALL",
+      "LAT",
+      "LON",
+      "ELEV_M",
+      "BEGIN",
+      "END",
+      "STNID",
+      "ELEV_M_SRTM_90m"
+    )
+  )
 })
